#
# spec file for package python3-psycopg2
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-psycopg2
Version:        2.6.1
Release:        4.7
Summary:        Python-PostgreSQL Database Adapter
License:        SUSE-LGPL-3.0-with-openssl-exception and (SUSE-LGPL-3.0-with-openssl-exception or ZPL-2.0)
Group:          Development/Languages/Python
Url:            http://initd.org/psycopg/
Source:         http://pypi.python.org/packages/source/p/psycopg2/psycopg2-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  postgresql-devel
BuildRequires:  python3-2to3
BuildRequires:  python3-Sphinx
BuildRequires:  python3-devel
Recommends:     postgresql-server
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
psycopg2 is a PostgreSQL database adapter for the Python programming
language.  psycopg2 was written with the aim of being very small and fast,
and stable as a rock.

psycopg2 is different from the other database adapter because it was
designed for heavily multi-threaded applications that create and destroy
lots of cursors and make a conspicuous number of concurrent INSERTs or
UPDATEs. psycopg2 also provide full asycronous operations and support
for coroutine libraries.

%package doc
Summary:        Documentation for psycopg python PostgreSQL database adapter
Group:          Documentation/HTML
Requires:       %{name} = %{version}

%description doc
Documentation and example files for the psycopg python PostgreSQL database adapter.

%prep
%setup -q -n psycopg2-%{version}

%build
CFLAGS="%{optflags} -fno-strict-aliasing" python3 setup.py build
cd doc/src && PYTHONPATH="$PYTHONPATH:%{buildroot}%{python3_sitearch}" make html
cd ../..
mv doc/src/_build/html doc/html
rm -rf doc/src # Remove junk

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}
rm -rf %{buildroot}%{python_sitearch}/psycopg2/tests # Don't package testsuite
%fdupes -s %{buildroot}/%{_mandir}  # Create symlinks for man pages
%fdupes %{buildroot}                # Create hardlinks for the rest

%files
%defattr(-,root,root,-)
%doc AUTHORS LICENSE NEWS README.rst
%{python3_sitearch}/psycopg2
%{python3_sitearch}/psycopg2-%{version}-py%{py3_ver}.egg-info

%files doc
%defattr(-,root,root)
%doc doc/html examples/

%changelog
* Tue Jun 16 2015 arun@gmx.de
- update to version 2.6.1:
  * Lists consisting of only "None" are escaped correctly
    (:ticket:`#285`).
  * Fixed deadlock in multithread programs using OpenSSL
    (:ticket:`#290`).
  * Correctly unlock the connection after error in flush
    (:ticket:`#294`).
  * Fixed "MinTimeLoggingCursor.callproc()" (:ticket:`#309`).
* Tue Feb 10 2015 arun@gmx.de
- specfile:
  * README->README.rst
  * build doc/html with Sphinx
- update to version 2.6:
  * Added support for large objects larger than 2GB.
  * Python time objects with a tzinfo specified and PostgreSQL timetz
    data are converted into each other (ticket #272).
  * Json apapter's str() returns the adapted content instead of the
    repr() (ticket #191).
- changes from version 2.5.5:
  * Named cursors used as context manager don't swallow the exception
    on exit (ticket #262).
  * cursor.description can be pickled (ticket #265).
  * Propagate read error messages in COPY FROM (ticket #270).
  * PostgreSQL time 24:00 is converted to Python 00:00 (ticket #278).
* Sat Jan 10 2015 arun@gmx.de
- specfile:
  * remove python(abi) requirement
* Thu Jan  8 2015 arun@gmx.de
- specfile: update copyright year
- update to version 2.5.4:
  * Added jsonb support for PostgreSQL 9.4 (ticket #226).
  * Fixed segfault if COPY statements are passed to execute() instead
    of using the proper methods (ticket #219).
  * Force conversion of pool arguments to integer to avoid potentially
    unbounded pools (ticket #220).
  * Cursors WITH HOLD don't begin a new transaction upon
    move/fetch/close (ticket #228).
  * Cursors WITH HOLD can be used in autocommit (ticket #229).
  * callproc() doesn't silently ignore an argument without a length.
  * Fixed memory leak with large objects (ticket #256).
  * The internal _psycopg.so module can be imported stand-alone (to
    allow modules juggling such as the one described in ticket #201).
- changes from version 2.5.3:
  * Work around pip issue #1630 making installation via pip -e git+url
    impossible (ticket #18).
  * Copy operations correctly set the cursor.rowcount attribute
    (ticket #180).
  * It is now possible to call get_transaction_status() on closed
    connections.
  * Fixed unsafe access to object names causing assertion failures in
    Python 3 debug builds (ticket #188).
  * Mark the connection closed if found broken on poll() (from ticket
    [#192] discussion)
  * Fixed handling of dsn and closed attributes in connection
    subclasses failing to connect (from ticket #192 discussion).
  * Added arbitrary but stable order to Range objects, thanks to Chris
    Withers (ticket #193).
  * Avoid blocking async connections on connect (ticket #194). Thanks
    to Adam Petrovich for the bug report and diagnosis.
  * Don't segfault using poorly defined cursor subclasses which forgot
    to call the superclass init (ticket #195).
  * Mark the connection closed when a Socket connection is broken, as
    it happens for TCP connections instead (ticket #196).
  * Fixed overflow opening a lobject with an oid not fitting in a
    signed int (ticket #203).
  * Fixed handling of explicit default cursor_factory=None in
    connection.cursor() (ticket #210).
  * Fixed possible segfault in named cursors creation.
  * Fixed debug build on Windows, thanks to James Emerton.
- changes from version 2.5.2:
  * Fixed segfault pickling the exception raised on connection error
    (ticket #170).
  * Meaningful connection errors report a meaningful message, thanks
    to Alexey Borzenkov (ticket #173).
  * Manually creating lobject with the wrong parameter doesn't
    segfault (ticket #187).
- changes from version 2.5.1:
  * Fixed build on Solaris 10 and 11 where the round() function is
    already declared (ticket #146).
  * Fixed comparison of Range with non-range objects (ticket
    [#164]). Thanks to Chris Withers for the patch.
  * Fixed double-free on connection dealloc (ticket #166). Thanks to
    Gangadharan S.A. for the report and fix suggestion.
* Mon Feb  3 2014 cfarrell@suse.com
- license update: SUSE-LGPL-3.0-with-openssl-exception and
  (SUSE-LGPL-3.0-with-openssl-exception or ZPL-2.0)
  The ZPL alternative is only offered for the zope database adapter. Also,
  the LGPL-3.0 used with psycopg2 has an exception for linking openssl
* Tue Apr 16 2013 jfunk@funktronics.ca
- Update to 2.5:
  - Added JSON adaptation.
  - Added support for PostgreSQL 9.2 range types.
  - `connection` and `cursor` objects can be used in ``with`` statements as
    context managers as specified by recent DBAPI extension.
  - Added `psycopg2.extensions.Diagnostics` object to get extended info from
    a database error.  Many thanks to Matthew Woodcraft for the implementation
    (ticket #149).
  - Added `connection.cursor_factory` attribute to customize the default
    object returned by `connection.cursor()`.
  - Added support for backward scrollable cursors. Thanks to Jon Nelson for
    the initial patch (ticket #108).
  - Added a simple way to customize casting of composite types into Python
    objects other than namedtuples. Many thanks to Ronan Dunklau and Tobias
    Oberstein for the feature development.
  - `connection.reset()` implemented using `DISCARD ALL` on server versions
    supporting it.
  - Properly cleanup memory of broken connections (ticket #148).
  - Fixed bad interaction of ``setup.py`` with other dependencies in
    Distribute projects on Python 3 (ticket #153).
  - Added support for Python 3.3.
  - Dropped support for Python 2.4. Please use Psycopg 2.4.x if you need it.
  - `psycopg2.errorcodes` map updated to PostgreSQL 9.2.
  - Dropped Zope adapter from source repository. ZPsycopgDA now has its own
    project at <http://github.com/psycopg/ZPsycopgDA>.
- Changes from 2.4.6:
  - Fixed 'cursor()' arguments propagation in connection subclasses and
    overriding of the 'cursor_factory' argument. Thanks to Corry Haines for
    the report and the initial patch (ticket #105).
  - Dropped GIL release during string adaptation around a function call
    invoking a Python API function, which could cause interpreter crash.
    Thanks to Manu Cupcic for the report (ticket #110).
  - Close a green connection if there is an error in the callback. Maybe a
    harsh solution but it leaves the program responsive (ticket #113).
  - 'register_hstore()', 'register_composite()', 'tpc_recover()' work with
    RealDictConnection and Cursor (ticket #114).
  - Fixed broken pool for Zope and connections re-init across ZSQL methods in
    the same request (tickets #123, #125, #142).
  - connect() raises an exception instead of swallowing keyword arguments when
    a connection string is specified as well (ticket #131).
  - Discard any result produced by 'executemany()' (ticket #133).
  - Fixed pickling of FixedOffsetTimezone objects (ticket #135).
  - Release the GIL around PQgetResult calls after COPY (ticket #140).
  - Fixed empty strings handling in composite caster (ticket #141).
  - Fixed pickling of DictRow and RealDictRow objects.
* Thu Nov 22 2012 toddrme2178@gmail.com
- Removed openSUSE 11.4 spec file workarounds
* Fri May 25 2012 highwaystar.ru@gmail.com
- python3 package added
